@@ -348,7 +348,7 @@ def load_train_data_file(train_datafile, target, keras_options, model_options, v
     print('Loaded a small data sample of size = %s into pandas dataframe to analyze...' %(train_small.shape,))
     ### classify variables using the small dataframe ##
     print('    Classifying variables using data sample in pandas...')
-    var_df1, cat_vocab_dict = classify_features_using_pandas(train_small, target, model_options, verbose=verbose)
+    train_small, var_df1, cat_vocab_dict = classify_features_using_pandas(train_small, target, model_options, verbose=verbose)
 
     ##########    Just transfer all the values from var_df to cat_vocab_dict  ##################################
     for each_key in var_df1:
@@ -497,6 +497,11 @@ def load_train_data_file(train_datafile, target, keras_options, model_options, v
     ##### F E A T U R E    E N G I N E E R I N G   H E R E              #############
     #################################################################################
     def process_boolean(features, target):
+        """
+        This is how you convert all your boolean features into float variables.
+        The reason you have to do this is because tf.keras does not know how to handle boolean types.
+        It takes as input an ordered dict named features and returns the same in features format.
+        """
         for feature_name in features:
             if feature_name in BOOLS:
                 # Cast boolean feature values to string.
@@ -644,6 +649,7 @@ def load_train_data_frame(train_small, target, keras_options, model_options, ver
     train_small = copy.deepcopy(train_small)
     DS_LEN = model_options['DS_LEN']
     #### do this for dataframes ##################
+
     try:
         batch_size = keras_options["batchsize"]
         if isinstance(keras_options["batchsize"], str):
@@ -701,7 +707,7 @@ def load_train_data_frame(train_small, target, keras_options, model_options, ver
 
     ###   Cat_Vocab_Dict contains all info about vocabulary in each variable and their size
     print('    Classifying variables using data sample in pandas...')
-    var_df, cat_vocab_dict = classify_features_using_pandas(train_small, target, model_options, verbose=verbose)
+    train_small, var_df, cat_vocab_dict = classify_features_using_pandas(train_small, target, model_options, verbose=verbose)
 
     ##########    Just transfer all the values from var_df to cat_vocab_dict  ##################################
     for each_key in var_df:
